Insertar imagen

Insertar imagen | TOC

El botón insertar imagen abre la siguiente ventana.
Tu sólo tienes que escribir la URL de la imagen que quieres que aparezca y escribir una descripción de esta, esta descripción aparecera como un texto alternativo que describa la imagen.
Descripción de los campos:

Image URL | URL de la imagen.
Image description | Descripción alternativa del contenido de la imagen.
Dimentions | Altura/anchura de la imagen.
Alignment | Alineamiento, útil cuando colocas texto alrededor de la imagen.
Border | Anchura del borde.
VSpace | Espacio vertical, útil cuando colocas texto alrededor de la imagen.
HSpace | Espacio horizontal, útil cuando colocas texto alrededor de la imagen.

Ir a: Lista de contenidos | Top